@@ -817,7 +817,7 @@ cherokee_header_parse (cherokee_header_t *hdr, cherokee_buffer_t *buffer, cherok
 	/* Check the buffer content
 	 */
 	if ((buffer->buf == NULL) || (buffer->len < 5)) {
-		LOG_ERROR_S ("Calling cherokee_header_parse() with an empty header\n");
+		LOG_ERROR_S (CHEROKEE_ERROR_HEADER_EMPTY);
 		return ret_error;
 	}
 
@@ -837,10 +837,12 @@ cherokee_header_parse (cherokee_header_t *hdr, cherokee_buffer_t *buffer, cherok
 		 */
 		ret = has_header_request (hdr, buffer, buffer->len);
 		if (ret != ret_ok) {
-			if (ret == ret_not_found)
-				LOG_ERROR("EOH not found:\n===\n%s===\n", buffer->buf);
-			else
-				LOG_ERROR("Too many initial CRLF:\n===\n%s===\n", buffer->buf);
+			if (ret == ret_not_found) {
+				LOG_ERROR (CHEROKEE_ERROR_HEADER_NO_EOH,
+					   buffer->len, buffer->buf);
+			} else {
+				LOG_ERROR_S (CHEROKEE_ERROR_HEADER_TOO_MANY_CRLF);
+			}
 			return ret_error;
 		}
 	}
@@ -1050,7 +1052,7 @@ cherokee_header_parse (cherokee_header_t *hdr, cherokee_buffer_t *buffer, cherok
 		}
 
 		if (ret < ret_ok) {
-			LOG_ERROR_S ("Failed to add_(un)known_header()\n");
+			LOG_ERROR_S (CHEROKEE_ERROR_HEADER_ADD_HEADER);
 			*header_end = chr_header_end;
 			return ret;
 		}
