@@ -79,7 +79,8 @@ cherokee_post_mrproper (cherokee_post_t *post)
 	if (! cherokee_buffer_is_empty (&post->tmp_file)) {
 		re = unlink (post->tmp_file.buf);
 		if (unlikely (re != 0)) {
-			LOG_ERRNO (errno, cherokee_err_error, "Couldn't remove %s: %s\n", post->tmp_file.buf);
+			LOG_ERRNO (errno, cherokee_err_error, 
+				   CHEROKEE_ERROR_POST_REMOVE_TEMP, post->tmp_file.buf);
 		}
 
 		TRACE(ENTRIES, "Removing '%s'\n", post->tmp_file.buf);
