@@ -64,11 +64,17 @@ typedef struct {
 
 
 ret_t cherokee_source_interpreter_new       (cherokee_source_interpreter_t **src);
-ret_t cherokee_source_interpreter_configure (cherokee_source_interpreter_t  *src, cherokee_config_node_t *conf);
 
-ret_t cherokee_source_interpreter_add_env   (cherokee_source_interpreter_t *src, char *env, char *val);
-ret_t cherokee_source_interpreter_spawn     (cherokee_source_interpreter_t *src,
-					     cherokee_logger_t             *logger);
+ret_t cherokee_source_interpreter_configure (cherokee_source_interpreter_t  *src,
+					     cherokee_config_node_t         *conf,
+					     int                             prio);
+
+ret_t cherokee_source_interpreter_add_env   (cherokee_source_interpreter_t  *src,
+					     char                           *env,
+					     char                           *val);
+
+ret_t cherokee_source_interpreter_spawn     (cherokee_source_interpreter_t  *src,
+					     cherokee_logger_t              *logger);
 
 ret_t cherokee_source_interpreter_connect_polling (cherokee_source_interpreter_t *src, 
 						   cherokee_socket_t             *socket,
